@@ -6,6 +6,9 @@ use Benchmark qw/timethese cmpthese/;
 use Const::Fast;
 use Parse::Syslog::Line;
 
+# Disable warnings
+$ENV{PARSE_SYSLOG_LINE_QUIET} = 1;
+
 const my @msgs => (
     q|<11>Jan  1 00:00:00 mainfw snort[32640]: [1:1893:4] SNMP missing community string attempt [Classification: Misc Attack] [Priority: 2]: {UDP} 1.2.3.4:23210 -> 5.6.7.8:161|,
     q|<11>Jan  1 00:00:00 11.22.33.44 dhcpd: DHCPINFORM from 172.16.2.137 via vlan3|,
@@ -21,6 +24,8 @@ const my @msgs => (
     q|2015 Nov 13 13:40:01 ether application: JSON log is: {"src_ip":"1.2.3.4","src_port":35235}|,
     q|2015 Nov 13 13:40:01 ether application: this is words with some splunk k/v at the end: k1=v1, k2=v2, k3=v3|,
     q|May 24 09:14:21 deprecation GoogleSoftwareUpdateAgent[22548]: 2018-05-24 09:14:21.050 GoogleSoftwareUpdateAgent[22548/0x70000b057000] [lvl=2] -[KSAgentApp(PrivateMethods) setUpLoggerOutputForVerboseMode:] Agent default/global settings: <KSAgentSettings:0x1003390a0 bundleID=com.google.Keystone.Agent lastCheck=2018-05-24 00:07:32 +0000 lastServerCheck=2018-05-24 00:07:31 +0000 lastCheckStart=2018-05-24 16:14:19 +0000 checkInterval=18000.000000 uiDisplayInterval=604800.000000 sleepInterval=1800.000000 jitterInterval=900 maxRunInterval=0.000000 isConsoleUser=1 ticketStorePath=/Users/brad/Library/Google/GoogleSoftwareUpdate/TicketStore/Keystone.ticketstore runMode=3 daemonUpdateEngineBrokerServiceName=com.google.Keystone.Daemon.UpdateEngine daemonAdministrationServiceName=com.google.Keystone.Daemon.Administration alwaysPromptForUpdates=0 lastUIDisplayed=(null) alwaysShowStatusItem=0 updateCheckTag=(null) printResults=NO userInitiated=NO>|,
+    q|2015 Nov 13 13:40:01 ether application: [lvl=2] [foo x=1] some context [bar x=3 t=4]|,
+    q|2015 Nov 13 13:40:01 ether application: [prop@12345 x="2"] some context|,
 );
 
 my $last = '';
@@ -39,21 +44,21 @@ my $results = timethese(50_000, {
     'Defaults' => sub {
         $stub->('Defaults');
     },
-    'NormalizeToUTC' => sub {
-        local $Parse::Syslog::Line::NormalizeToUTC  = 1;
-        $stub->('NormalizeToUTC');
-    },
+    #'NormalizeToUTC' => sub {
+        #local $Parse::Syslog::Line::NormalizeToUTC  = 1;
+        #$stub->('NormalizeToUTC');
+    #},
     'PruneEmpty' => sub {
         local $Parse::Syslog::Line::PruneEmpty      = 1;
         $stub->('PruneEmpty');
     },
-    'No Dates, Pruned' => sub {
+    'NoDatesPruned' => sub {
         local $Parse::Syslog::Line::DateParsing     = 0;
         local $Parse::Syslog::Line::PruneRaw        = 1;
         local $Parse::Syslog::Line::PruneEmpty      = 1;
         $stub->('No Dates, Pruned');
     },
-    'No Dates' => sub {
+    'NoDates' => sub {
         local $Parse::Syslog::Line::DateParsing     = 0;
         $stub->('No Dates');
     },
@@ -65,7 +70,15 @@ my $results = timethese(50_000, {
         local $Parse::Syslog::Line::AutoDetectKeyValues = 1;
         $stub->('KV');
     },
-    'SDATA' => sub {
+    'NoRFCSDATA' => sub {
+        local $Parse::Syslog::Line::RFC5424StructuredData = 0;
+        $stub->('SDATA');
+    },
+    'StrictRFC' => sub {
+        local $Parse::Syslog::Line::RFC5424StructuredDataStrict = 1;
+        $stub->('SDATA');
+    },
+    'AutoSDATA' => sub {
         local $Parse::Syslog::Line::AutoDetectJSON = 1;
         local $Parse::Syslog::Line::AutoDetectKeyValues = 1;
         $stub->('SDATA');
